@@ -1,14 +1,20 @@
 using LuxorGraphPlot, Graphs
-using Test
+using Test, Documenter
+
+@testset "layouts" begin
+    include("layouts/layouts.jl")
+end
+
+@testset "graphplot" begin
+    include("graphplot.jl")
+end
 
 @testset "nodes" begin
     include("nodes.jl")
 end
 
-@testset "layouts" begin
-    include("layouts.jl")
+@testset "nodestore" begin
+    include("nodestore.jl")
 end
 
-@testset "graphplot" begin
-    include("graphplot.jl")
-end
\ No newline at end of file
+Documenter.doctest(LuxorGraphPlot)
\ No newline at end of file
